@@ -1182,6 +1182,11 @@ cleanup:
 #endif
 }
 
+static inline MagickBooleanType IsEmptyOutline(FT_Outline outline)
+{
+  return((outline.n_points == 0) || (outline.n_contours <= 0));
+}
+
 static int TraceCubicBezier(FT_Vector *p,FT_Vector *q,FT_Vector *to,
   DrawInfo *draw_info)
 {
@@ -1585,9 +1590,10 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     ft_status=FT_Get_Glyph(face->glyph,&glyph.image);
     if (ft_status != 0)
       continue;
-    if (glyph.image->format != FT_GLYPH_FORMAT_OUTLINE)
-      continue;
     outline=((FT_OutlineGlyph) glyph.image)->outline;
+    if ((glyph.image->format != FT_GLYPH_FORMAT_OUTLINE) &&
+        (IsEmptyOutline(outline) == MagickFalse))
+      continue;
     ft_status=FT_Outline_Get_BBox(&outline,&bounds);
     if (ft_status != 0)
       continue;
@@ -1612,7 +1618,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         */
         annotate_info->affine.tx=glyph.origin.x/64.0;
         annotate_info->affine.ty=(-glyph.origin.y/64.0);
-        if ((outline.n_contours > 0) && (outline.n_points > 0))
+        if (IsEmptyOutline(outline) == MagickFalse)
           ft_status=FT_Outline_Decompose(&outline,&OutlineMethods,
             annotate_info);
       }
