@@ -81,18 +81,20 @@ static const CoderMapInfo
   CoderMap[] =
   {
     { "3FR", "DNG" },
-    { "3GP", "MPEG" },
-    { "3G2", "MPEG" },
+    { "3GP", "VIDEO" },
+    { "3G2", "VIDEO" },
     { "8BIM", "META" },
     { "8BIMTEXT", "META" },
     { "8BIMWTEXT", "META" },
     { "AFM", "TTF" },
     { "A", "RAW" },
     { "AI", "PDF" },
+    { "APNG", "VIDEO" },
     { "APP1JPEG", "META" },
     { "APP1", "META" },
     { "ARW", "DNG" },
-    { "AVI", "MPEG" },
+    { "AVI", "VIDEO" },
+    { "AVIF", "HEIC" },
     { "BIE", "JBIG" },
     { "BMP2", "BMP" },
     { "BMP3", "BMP" },
@@ -178,14 +180,15 @@ static const CoderMapInfo
     { "KDC", "DNG" },
     { "LOGO", "MAGICK" },
     { "M", "RAW" },
-    { "M2V", "MPEG" },
-    { "M4V", "MPEG" },
+    { "M2V", "VIDEO" },
+    { "M4V", "VIDEO" },
     { "MEF", "DNG" },
-    { "MKV", "MPEG" },
+    { "MKV", "VIDEO" },
     { "MNG", "PNG" },
-    { "MOV", "MPEG" },
-    { "MP4", "MPEG" },
-    { "MPG", "MPEG" },
+    { "MOV", "VIDEO" },
+    { "MP4", "VIDEO" },
+    { "MPEG", "VIDEO" },
+    { "MPG", "VIDEO" },
     { "MPRI", "MPR" },
     { "MEF", "DNG" },
     { "MRW", "DNG" },
@@ -245,11 +248,12 @@ static const CoderMapInfo
     { "UBRL6", "BRAILLE" },
     { "VDA", "TGA" },
     { "VST", "TGA" },
+    { "WEBM", "VIDEO" },
     { "WIZARD", "MAGICK" },
 #if defined(MAGICKCORE_WINGDI32_DELEGATE)
     { "WMF", "EMF" },
 #endif
-    { "WMV", "MPEG" },
+    { "WMV", "VIDEO" },
     { "WMZ", "WMF" },
     { "X3f", "DNG" },
     { "XMP", "META" },
