@@ -520,11 +520,11 @@ static char *SanitizeDelegateString(const char *source)
 
   static char
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
-    whitelist[] =
+    allowlist[] =
       "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789 "
       "$-_.+!;*(),{}|^~[]`\'><#%/?:@&=";
 #else
-    whitelist[] =
+    allowlist[] =
       "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789 "
       "$-_.+!;*(),{}|\\^~[]`\"><#%/?:@&=";
 #endif
@@ -532,7 +532,7 @@ static char *SanitizeDelegateString(const char *source)
   sanitize_source=AcquireString(source);
   p=sanitize_source;
   q=sanitize_source+strlen(sanitize_source);
-  for (p+=strspn(p,whitelist); p != q; p+=strspn(p,whitelist))
+  for (p+=strspn(p,allowlist); p != q; p+=strspn(p,allowlist))
     *p='_';
   return(sanitize_source);
 }
@@ -2209,7 +2209,7 @@ static MagickBooleanType LoadDelegateCache(LinkedListInfo *cache,
         /*
           Delegate element.
         */
-        delegate_info=(DelegateInfo *) AcquireMagickMemory(
+        delegate_info=(DelegateInfo *) AcquireQuantumMemory(1,
           sizeof(*delegate_info));
         if (delegate_info == (DelegateInfo *) NULL)
           ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
