@@ -1382,11 +1382,13 @@ static Image *OptimizeLayerFrames(const Image *image,
     if ( disposals[i] == DelDispose ) {
       size_t time = 0;
       while ( disposals[i] == DelDispose ) {
-        time += curr->delay*1000/curr->ticks_per_second;
+        time += (size_t) (curr->delay*1000*
+          PerceptibleReciprocal((double) curr->ticks_per_second));
         curr=GetNextImageInList(curr);
         i++;
       }
-      time += curr->delay*1000/curr->ticks_per_second;
+      time += (size_t) (curr->delay*1000*
+        PerceptibleReciprocal((double) curr->ticks_per_second));
       prev_image->ticks_per_second = 100L;
       prev_image->delay = time*prev_image->ticks_per_second/1000;
     }
@@ -1935,7 +1937,7 @@ MagickExport void CompositeLayers(Image *destination,
 %           Images with negative offsets will be clipped.
 %
 %        TrimBoundsLayer: Determine the overall bounds of all the image
-%           layers just as in "MergeLayer", then adjust the the canvas
+%           layers just as in "MergeLayer", then adjust the canvas
 %           and offsets to be relative to those bounds, without overlaying
 %           the images.
 %
