@@ -324,7 +324,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
         */
         if (head != (Cluster *) NULL)
           {
-            cluster->next=(Cluster *) AcquireMagickMemory(
+            cluster->next=(Cluster *) AcquireQuantumMemory(1,
               sizeof(*cluster->next));
             cluster=cluster->next;
           }
@@ -1037,7 +1037,7 @@ MagickExport MagickBooleanType GetImageDynamicThreshold(const Image *image,
         */
         if (head != (Cluster *) NULL)
           {
-            cluster->next=(Cluster *) AcquireMagickMemory(
+            cluster->next=(Cluster *) AcquireQuantumMemory(1,
               sizeof(*cluster->next));
             cluster=cluster->next;
           }
@@ -1412,13 +1412,13 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
           {
             if (node == head)
               {
-                node->child=(IntervalTree *) AcquireMagickMemory(
+                node->child=(IntervalTree *) AcquireQuantumMemory(1,
                   sizeof(*node->child));
                 node=node->child;
               }
             else
               {
-                node->sibling=(IntervalTree *) AcquireMagickMemory(
+                node->sibling=(IntervalTree *) AcquireQuantumMemory(1,
                   sizeof(*node->sibling));
                 node=node->sibling;
               }
@@ -1438,7 +1438,7 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
         }
       if (left != head->left)
         {
-          node->sibling=(IntervalTree *) AcquireMagickMemory(
+          node->sibling=(IntervalTree *) AcquireQuantumMemory(1,
             sizeof(*node->sibling));
           node=node->sibling;
           if (node == (IntervalTree *) NULL)
